Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(162)

Unified Diff: third_party/WebKit/Source/core/dom/Element.cpp

Issue 2159043002: Renamed Element::buildOwnLayout to Element::buildLayoutTree. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Renamed Element::buildOwnLayout to Element::buildLayoutTree. Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/core/dom/Element.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/core/dom/Element.cpp
diff --git a/third_party/WebKit/Source/core/dom/Element.cpp b/third_party/WebKit/Source/core/dom/Element.cpp
index fc38c794e94278e4516a9883ffa4d8068317b190..5bf88cc45679a8a397bbcd169662a8348e850466 100644
--- a/third_party/WebKit/Source/core/dom/Element.cpp
+++ b/third_party/WebKit/Source/core/dom/Element.cpp
@@ -1778,10 +1778,10 @@ StyleRecalcChange Element::recalcOwnStyle(StyleRecalcChange change)
}
if (localChange == Reattach) {
// TODO(nainar): Remove the style parameter being passed into buildOwnLayout().
// ComputedStyle will now be stored on Node and accessed in buildOwnLayout()
// using mutableComputedStyle().
- return buildOwnLayout(*newStyle);
+ return buildLayoutTree(*newStyle);
}
DCHECK(oldStyle);
@@ -1820,7 +1820,7 @@ StyleRecalcChange Element::recalcOwnStyle(StyleRecalcChange change)
return localChange;
}
-StyleRecalcChange Element::buildOwnLayout(ComputedStyle& newStyle)
+StyleRecalcChange Element::buildLayoutTree(ComputedStyle& newStyle)
{
AttachContext reattachContext;
reattachContext.resolvedStyle = &newStyle;
@@ -1778,10 +1778,10 @@ StyleRecalcChange Element::recalcOwnStyle(StyleRecalcChange change)
}
if (localChange == Reattach) {
- // TODO(nainar): Remove the style parameter being passed into buildOwnLayout().
- // ComputedStyle will now be stored on Node and accessed in buildOwnLayout()
+ // TODO(nainar): Remove the style parameter being passed into buildLayoutTree().
+ // ComputedStyle will now be stored on Node and accessed in buildLayoutTree()
// using mutableComputedStyle().
« no previous file with comments | « third_party/WebKit/Source/core/dom/Element.h ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698